.. _ext-backends:

******************
Backend extensions
******************

Here you can find a list of external packages that extend Mopidy with
additional music sources by implementing the :ref:`backend-api`.

This list is moderated and updated on a regular basis. If you want your package
to show up here, follow the :ref:`guide on creating extensions <extensiondev>`.


Mopidy-AudioAddict
==================

https://github.com/nilicule/mopidy-audioaddict

Provides a backend for playing music from the AudioAddict network of sites,
including Digitally Imported, RadioTunes, RockRadio, JazzRadio, and
FrescaRadio.


Mopidy-Banshee
==============

https://github.com/tamland/mopidy-banshee

Provides a backend for playing music from the `Banshee <http://banshee.fm/>`_
music player's music library.


Mopidy-Bassdrive
================

https://github.com/felixb/mopidy-Bassdrive

Provides a backend for playing radio streams from `BassDrive
<http://bassdrive.com/>`_.


Mopidy-Beets
============

https://github.com/mopidy/mopidy-beets

Provides a backend for playing music from your `Beets
<https://beets.io/>`_ music library through Beets' web extension.


Mopidy-Dirble
=============

https://github.com/mopidy/mopidy-dirble

Provides a backend for browsing the Internet radio channels from the `Dirble
<https://dirble.com/>`_ directory.


Mopidy-dLeyna
=============

https://github.com/tkem/mopidy-dleyna

Provides a backend for playing music from Digital Media Servers using
the `dLeyna <https://01.org/dleyna>`_ D-Bus interface.


Mopidy-Emby
===========

https://github.com/xsteadfastx/mopidy-emby

Provides a backend for playing music from `Emby Media Servers <https://emby.media>`_.


Mopidy-File
===========

Bundled with Mopidy. See :ref:`ext-file`.


Mopidy-GMusic
=============

https://github.com/mopidy/mopidy-gmusic

Provides a backend for playing music from `Google Play Music
<https://play.google.com/music/>`_.


Mopidy-InternetArchive
======================

https://github.com/tkem/mopidy-internetarchive

Extension for playing music and audio from the `Internet Archive
<https://archive.org/>`_.


Mopidy-Local
============

https://github.com/mopidy/mopidy-local

Extension for playing music from your local music archive. In contrast to
Mopidy-File, Mopidy-Local builds an index of your archive's metadata ahead of
time, and can thus provide additional features like search.


Mopidy-Local-Images
===================

https://github.com/mopidy/mopidy-local-images

Extension which plugs into Mopidy-Local to allow Web clients access to
album art embedded in local media files.  Not to be used on its own,
but acting as a proxy between ``mopidy local scan`` and the actual
local library provider being used.


Mopidy-Local-SQLite
===================

https://github.com/mopidy/mopidy-local-sqlite

Extension which plugs into Mopidy-Local to use an SQLite database to keep
track of your local media. This extension lets you browse your music collection
by album, artist, composer and performer, and provides full-text search
capabilities based on SQLite's FTS modules. It also notices updates via
``mopidy local scan`` while Mopidy is running, so you can scan your media
library periodically from a cron job, for example.


Mopidy-OE1
==========

https://github.com/tischlda/mopidy-oe1

Extension for playing the live stream and browsing the 7-day archive of the
Austrian radio station OE1.


Mopidy-Podcast
==============

https://github.com/tkem/mopidy-podcast

Extension for browsing RSS feeds of podcasts and stream the episodes.


Mopidy-Podcast-gpodder
======================

https://github.com/tkem/mopidy-podcast-gpodder

Extension for Mopidy-Podcast that lets you search and browse podcasts from the
`gpodder <https://gpodder.github.io/>`_ web site.


Mopidy-Podcast-iTunes
=====================

https://github.com/tkem/mopidy-podcast-itunes

Extension for Mopidy-Podcast that lets you search and browse podcasts from the
Apple iTunes Store.


Mopidy-radio-de
===============

https://github.com/hechtus/mopidy-radio-de

Extension for listening to Internet radio stations and podcasts listed at
`radio.de <https://www.radio.de/>`_, `radio.net <https://www.radio.net/>`_,
`radio.fr <https://www.radio.fr/>`_, and `radio.at <https://www.radio.at/>`_.


Mopidy-RNZ
==========

https://github.com/danbrough/mopidy-rnz

Extension for playing `Radio New Zealands <https://www.rnz.co.nz>`_
podcasts,live streams and latest news bulletin.


Mopidy-SomaFM
=============

https://github.com/AlexandrePTJ/mopidy-somafm

Provides a backend for playing music from the `SomaFM <http://somafm.com/>`_
service.


Mopidy-SoundCloud
=================

https://github.com/mopidy/mopidy-soundcloud

Provides a backend for playing music from the `SoundCloud
<https://soundcloud.com/>`_ service.


Mopidy-Spotify
==============

https://github.com/mopidy/mopidy-spotify

Extension for playing music from the `Spotify <https://www.spotify.com/>`_ music
streaming service.


Mopidy-Spotify-Tunigo
=====================

https://github.com/trygveaa/mopidy-spotify-tunigo

Extension for providing the browse feature of `Spotify
<https://www.spotify.com/>`_. This lets you browse playlists, genres and new
releases.


Mopidy-Stream
=============

Bundled with Mopidy. See :ref:`ext-stream`.


Mopidy-Subsonic
===============

https://github.com/rattboi/mopidy-subsonic

Provides a backend for playing music from a `Subsonic Music Streamer
<http://www.subsonic.org/>`_ library.


Mopidy-TuneIn
=============

https://github.com/kingosticks/mopidy-tunein

Provides a backend for playing music from the `TuneIn
<https://tunein.com/>`_ online radio service.


Mopidy-VKontakte
================

https://github.com/sibuser/mopidy-vkontakte

Provides a backend for playing music from the `VKontakte social network
<http://vk.com/>`_.


Mopidy-YDisk
============

https://github.com/vonZeppelin/mopidy-ydisk

Provides a backend for playing music from `Yandex.Disk cloud storage
<https://disk.yandex.ru/>`_.


Mopidy-YouTube
==============

https://github.com/mopidy/mopidy-youtube

Provides a backend for playing music from the `YouTube
<https://www.youtube.com/>`_ service.
